@@ -2,6 +2,8 @@
 import os
 from masonite.provider import ServiceProvider
 from masonite.view import View
+from masonite.js_routes.commands.GenerateCommand import GenerateCommand
+from masonite.js_routes.commands.InstallCommand import InstallCommand
 
 from ..generator import RoutesGenerator
 
@@ -16,7 +18,8 @@ class JSRoutesProvider(ServiceProvider):
 
     def register(self):
         """Register objects into the Service Container."""
-        pass
+        self.app.bind("GenerateCommand", GenerateCommand())
+        self.app.bind("InstallCommand", InstallCommand())
 
     def boot(self, view: View):
         """Boots services required by the container."""
